### References used so far in the creation of PySprint package

* [1] T. Grósz, „Mikrostruktúrált optikai szálak diszperziójának vizsgálata spektrális interferometriával” Ph.D.  thesis,  University of Szeged, Department of Optics and Quantum Electronics, Szeged (2017).
* [2] A. Kovács, „Optikai elemek fázistulajdonságainak interferometrikus vizsgálata,” Ph.D.  thesis,  University of Szeged, Department of Optics and Quantum Electronics, Szeged (2000).
* [3] C. Dorrer, N. Belabas, J-P. Likforman, and M. Joffre, „Spectral resolution and sampling issues in Fourier-transform spectral interferometry”, J. Opt. Soc. Am. B 17, 1795 (2000)
* [4] L. Huang, Q. Kemao, B. Pan, and A. K. Asundi, „Comparison of Fourier transform, windowed  Fourier  transform,  and  wavelet  transform  methods  for  phase  extraction  from  asingle  fringe  pattern  in  fringe  projection  profilometry,”  Opt.  Laser  Eng. 48,  141–148 (2010).
* [5]  Jean-Paul. Peak signal detection in realtime timeseries data [Msg 104]. Message posted to Stackoverflow [Internet]. 2014 [cited 2019.10.29.]. 
	   Available from: https://stackoverflow.com/questions/22583391/peak-signal-detection-in-realtime-timeseries-data.
* [6] J.-C. Diels, W. Rudolph: Ultrashort Laser Pulse Phenomena, 2nd Edition, Academic Press (2006).
* [7] Á. Börzsönyi: Spektrálisan bontott interferencián alapuló eljárás kidolgozása extrém kicsiny diszperzió mérésére, Master's thesis,  University of Szeged, Department of Optics and Quantum Electronics, Szeged (2006)
* [8] A. Kovács, Á. Börzsönyi, Z. Horváth, K. Osvay: A femtoszekundumos optika alapjai, online resource: http://titan.physx.u-szeged.hu/~julio/femto/FemtoOptika_130513.html
* [9] T. Grósz, A. Kovács, M. Kiss, R. Szipőcs: Measurement of higher order chromatic dispersion in a photonic bandgap fiber: comparative study of spectral interferometric methods, Appl. Opt. 53, 1929-1937, (2014)
* [10] R. D. Guenther: Modern Optics, Wiley & Sons (1990)
* [11] T. Grósz, A. Kovács, K. Mecseki, L. Gulyás, R. Szipőcs: Monitoring the dominance of higher-order chromatic dispersion with spectral interferometry using the stationary phase point method., Optics Communications. 338. 10.1016/j.optcom.2014.10.047. (2015)
* [12] P.  Hlubina,  D.  Ciprian,  and  L.Knyblová: Direct measurement of dispersion of the group  refractive  indices  of  quartz  crystal  by  white-light  spectral  interferometry,  Opt. Commun. 269, 8–13 (2007).
* [13] T. Oliphant:  Python for Scientific Computing, Computing in Science & Engineering. 9. 10-20. 10.1109/MCSE.2007.58. (2007)
* [14] K. Staszek, M. Bogusz: Simple fringe pattern normalization algorithm. IFAC Proceedings Volumes (IFAC-PapersOnline). 11. 353-356. 10.3182/20120523-3-CZ-3015.00067.  (2012)
* [15] Bernini, María & Federico, Alejandro & Kaufmann, Guillermo. Normalization of fringe patterns using the bidimensional empirical mode decomposition and the Hilbert transform., Applied optics. 48. 6862-9. 10.1364/AO.48.006862. (2009)
* [16] Dutt A., Rokhlin V. : Fast Fourier Transforms for Nonequispaced Data II, Applied and Computational Harmonic Analysis, Volume 2, Issue 1, January 1995, Pages 85-100(1995)
* [17] Greengard, Leslie & Lee, June-Yub.: Accelerating the Nonuniform Fast Fourier Transform, Society for Industrial and Applied Mathematics. 46. 443-454. 10.1137/S003614450343200X. (2004)